@@ -10,8 +10,11 @@ import re
 import sys
 import asyncio
 import logging
+import datetime as dt
 import traceback
 
+from google.protobuf import timestamp_pb2
+
 logging.basicConfig(
     level=logging.INFO,
     format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
@@ -150,8 +153,8 @@ T = TypeVar("T", bound=AlgorithmFn)
 
 @dataclass
 class Window:
-    time_from: int
-    time_to: int
+    time_from: dt.datetime
+    time_to: dt.datetime
     name: str
     version: str
     origin: str
@@ -167,9 +170,15 @@ def EmitWindow(window: Window) -> None:
     """
     LOGGER.info(f"Emitting window: {window}")
 
+    _time_from = timestamp_pb2.Timestamp()
+    _time_from.FromDatetime(window.time_from)
+
+    _time_to = timestamp_pb2.Timestamp()
+    _time_to.FromDatetime(window.time_to)
+
     window_pb = pb.Window()
-    window_pb.time_to = window.time_to
-    window_pb.time_from = window.time_from
+    window_pb.time_to = _time_from
+    window_pb.time_from = _time_to
     window_pb.window_type_name = window.name
     window_pb.window_type_version = window.version
     window_pb.origin = window.origin
@@ -389,7 +398,7 @@ class Processor(OrcaProcessorServicer):  # type: ignore
             current_time = int(time.time())  # Current timestamp in seconds
 
             if isinstance(algoResult, dict):
-                # For dictionary results, use struct_value
+                # for dictionary results, use struct_value
                 struct_value = struct_pb2.Struct()
                 json_format.ParseDict(algoResult, struct_value)
 
@@ -611,9 +620,11 @@ class Processor(OrcaProcessorServicer):  # type: ignore
                 result_type_pb = pb.ResultType.STRUCT
             elif algorithm.result_type == ArrayResult:  # type: ignore
                 result_type_pb = pb.ResultType.ARRAY
+            elif algorithm.result_type == NoneResult:  # type: ignore
+                result_type_pb = pb.ResultType.NONE
             else:
                 raise InvalidAlgorithmReturnType(
-                    f"Algorithm has return type {algorithm.result_type}, but expected one of `StructResult`, `ValueResult`, `ArrayResult`"
+                    f"Algorithm has return type {algorithm.result_type}, but expected one of `StructResult`, `ValueResult`, `ArrayResult`, `NoneResult`"
                 )
 
             ## add the result type
@@ -759,7 +770,7 @@ class Processor(OrcaProcessorServicer):  # type: ignore
             returnType = sig.return_annotation
             if not is_type_in_union(returnType, returnResult):  # type: ignore
                 raise InvalidAlgorithmReturnType(
-                    f"Algorithm has return type {sig.return_annotation}, but expected one of `StructResult`, `ValueResult`, `ArrayResult`"
+                    f"Algorithm has return type {sig.return_annotation}, but expected one of `StructResult`, `ValueResult`, `ArrayResult`, `NoneResult`"
                 )
 
             algorithm = Algorithm(
